<?php

/**
 * Plugin Name: WooCommerce Prominent Product Attributes
 * Plugin URI: http://code.tutsplus.com/tutorials/making-woocommerce-product-attributes-more-prominent--cms-25438
 * Description: Make WooCommerce product attributes more prominent by moving them out of the "more information" tab onto the top of the page on single product pages (requires WooCommerce to be activated).
 * Version: 1.0.0
 * Author: Rachel McCollin
 * Author URI: http://rachelmccollin.co.uk
 * License: GPL-3.0+
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Domain Path: /lang
 * Text Domain: tutsplus
 */

/**
 * Removes the "Additional Information" tab that displays the product attributes.
 * 
 * @param array $tabs WooCommerce tabs to display.
 * 
 * @return array WooCommerce tabs to display, minus "Additional Information".
 */
function tutsplus_remove_product_attributes_tab( $tabs ) {

    unset( $tabs['additional_information'] );
    
    return $tabs;

}

add_filter( 'woocommerce_product_tabs', 'tutsplus_remove_product_attributes_tab', 100 );

/**
 * Displays product attributes in the top right of the single product page.
 * 
 * @param $product
 */
function tutsplus_list_attributes( $product ) {
    
    global $product;
    global $post;

    $attributes = $product->get_attributes();

    if ( ! $attributes ) {

        return;

    }

    foreach ( $attributes as $attribute ) {

        // Get the taxonomy.
        $terms = wp_get_post_terms( $product->id, $attribute[ 'name' ], 'all' );
        $taxonomy = $terms[ 0 ]->taxonomy;

        // Get the taxonomy object.
        $taxonomy_object = get_taxonomy( $taxonomy );

        // Get the attribute label.
        $attribute_label = $taxonomy_object->labels->name;

        // Display the label followed by a clickable list of terms.
        echo get_the_term_list( $post->ID, $attribute[ 'name' ] , '<div class="attributes">' . $attribute_label . ': ' , ', ', '</div>' );

    }
        
}

add_action( 'woocommerce_product_meta_end', 'tutsplus_list_attributes' );